/*
SMSObject.m - SMS Framework
Copyright (C) 2005, Tim Ellis

This library is free software; you can redistribute it and/or
modify it under the terms of the GNU Lesser General Public
License as published by the Free Software Foundation; either
version 2.1 of the License, or (at your option) any later version.

This library is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
Lesser General Public License for more details.

You should have received a copy of the GNU Lesser General Public
License along with this library; if not, write to the Free Software
Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA

You dont need to use most of these NSDictionaries, the ones you want to look 
at are messageAndHeader with the data key, and the multipartInfo NSDictionary
which if present will tell you information about multipart SMS messages.

A good place to look for information on this is http://www.dreamfabric.com/sms/

NSDictionary smscInfo & NSDictionary senderInfo
	npi = NSNumber for Number Plan Identification (see SMS.h)
	type = NSNumber for type of address (see SMS.h)
	number = NSString for service center number (it can be alphanumeric)

NSDictionary messageAndHeader
	data = NSString containing the message
	header = NSString containing the header
	
timestamp is an NSDate.

NSDictionary firstOctetInfo
	replypath = NSNumber representing reply path
	udhi = NSNumber representing if user data header is present (it will be if its a multipart message)
	sri = NSNumber representing status report indication
	mms = NSNumber representing the More Messages to Send value (no, dont use this to check for multipart messages)
	mti = NSString representing the Message Transfer Index

NSDictionary tpDcsInfo
	dcstype = NSNumber representing data coding scheme type (SMS.h)
	msgalphabet = NSNumber representing the alphabet used by the message (SMS.h)
	msgclass = NSNumber class of message (SMS.h)
	msgcompression = NSNumber telling you if the message was compressed (SMS.h)
	msgclassvalidity = NSNumber tells you GDC validity (SMS.h)
	indactivity = NSNumber representing if an indication is active (SMS.h)
	indtype = NSNumber representing the indication type (SMS.h)

NSDictionary multipartInfo
	smsid = NSNumber - the id of the multipart message (this is the same for all parts of one message allowing you to identify all the parts) 
	total = NSNumber - total amount of parts to the multipart message
	partno = NSNumber - part number of multipart message
*/

#ifdef __APPLE__
#import <Cocoa/Cocoa.h>
#else
#include <Foundation/Foundation.h>
#endif

@interface SMSObject : NSObject {
	NSDictionary *smscInfo, *messageAndHeader, *firstOctetInfo, *senderInfo, *tpDcsInfo, *multipartInfo;
	NSDate *timestamp;
}

- (void) setSmscInfo:(NSDictionary*)dict;
- (void) setMessageAndHeader:(NSDictionary*)dict;
- (void) setFirstOctetInfo:(NSDictionary*)dict;
- (void) setSenderInfo:(NSDictionary*)dict;
- (void) setTpDcsInfo:(NSDictionary*)dict;
- (void) setMultipartInfo:(NSDictionary*)dict;
- (void) setTimestamp:(NSDate*)date;
- (NSDictionary*) smscInfo;
- (NSDictionary*) messageAndHeader;
- (NSDictionary*) firstOctetInfo;
- (NSDictionary*) senderInfo;
- (NSDictionary*) tpDcsInfo;
- (NSDictionary*) multipartInfo;
- (NSDate*) timestamp;

@end
